@@ -250,6 +250,34 @@ class GseClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def JoinGameServerSessionBatch(self, request):
+        """This API is used to join game server sessions in batch.
+
+        :param request: Request instance for JoinGameServerSessionBatch.
+        :type request: :class:`tencentcloud.gse.v20191112.models.JoinGameServerSessionBatchRequest`
+        :rtype: :class:`tencentcloud.gse.v20191112.models.JoinGameServerSessionBatchResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("JoinGameServerSessionBatch", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.JoinGameServerSessionBatchResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def SearchGameServerSessions(self, request):
         """This API is used to search in the list of game server sessions.
 
